@@ -12,7 +12,7 @@ import glob
 import os.path as path
 import importlib
 
-__VERSION__ = "0.1.7"
+__VERSION__ = "0.1.10"
 init() #colorama
 
 class credentials:
@@ -28,9 +28,6 @@ class credentials:
 
 
 
-
-
-
 '''AWS Stuff'''
 
 def createRepo(repoName, repoDesc, creds):
@@ -269,7 +266,9 @@ def makePyModules(py_fileList, stage):
         relPath = path.relpath(pyFile)
         module = relPath.split(".")[0] + "." + "lambda_handler"
         funName = relPath.split(".")[0].replace('/', '_')
-        addTosls(relPath, module, funName, "python3", stage)
+        funName = funName[:-15]
+        addTosls(relPath, module, funName, "python3.7", stage)
+        print(module)
 
 
 def makeJSModules(js_fileList, stage):
@@ -277,6 +276,7 @@ def makeJSModules(js_fileList, stage):
         relPath = path.relpath(jsFile)
         module = relPath.split(".")[0] + "." + "handler"
         funName = relPath.split(".")[0].replace('/', '_')
+        funName = funName[:-5]
         addTosls(relPath, module, funName, "nodejs12.x", stage)
 
 
@@ -407,7 +407,6 @@ def cbCLI(creds):
 
 
 
-
 def skipCLI(service, region, stage):
     createSls(service, region, stage)
     js_fileList = glob.glob(os.getcwd() + "/**/index.js", recursive=True)
